==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Добавить в альбом</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Все изображения</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Открыть  Изображение</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Вы не обладаете правами  на просмотр данного изображения </translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата изменения</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата захвата</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим экспозиции</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Программа экспозиции</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Время экспозиции</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Вспышка</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Диафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусное расстояние</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс диафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим замера экспозиции</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс белого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсация вспышки</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель линзы</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Цветовое пространство</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камеры</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Ярлык</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Размер 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>По размеру окна</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Извлечь текст</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Показать окно навигации</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Скрыть окно навигации</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в  файловом менеджере </translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Введите новое имя</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Изображение не найдено</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Файл изображения не найден</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.14.orig.tar.xz: image-editor-1.0.14/libimageviewer/translations/libimageviewer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Добавить в альбом</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Все изображения</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Открыть  Изображение</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Вы не обладаете правами  на просмотр данного изображения </translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата изменения</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата захвата</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим экспозиции</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Программа экспозиции</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Время экспозиции</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Вспышка</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Диафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусное расстояние</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс диафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим замера экспозиции</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс белого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсация вспышки</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель линзы</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Цветовое пространство</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камеры</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Ярлык</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Размер 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>По размеру окна</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Извлечь текст</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный Экран</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Распечатать</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Показать окно навигации</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Скрыть окно навигации</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отобразить в  файловом менеджере </translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация о изображении</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Введите новое имя</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Изображение не найдено</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Файл изображения не найден</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
